.. _profile:

**profile** - Edit and manage profiles
======================================

Usage
-----

.. code::

    e4s-cl [ OPTIONS ] profile SUBCOMMAND { ARGUMENTS }

    SUBCOMMAND := { create | copy | delete | edit | list |
                    show | select | unselect | detect | dump }

Description
-----------

.. automodule:: e4s_cl.cli.commands.profile

Sub-Commands
------------

.. toctree::
   :maxdepth: 1
   
   copy
   create
   delete
   detect
   diff
   dump 
   edit
   list
   select
   show
   unselect

